pub enum Certainty {
Possible,
Likely,
Confident,
Certain,
}Expand description
Certainty levels for the data
Variants
Possible
This datum is possibly correct, but it is a guess
Likely
This datum is likely to be correct, but we are not sure
Confident
We’re confident about this datum, but there is a chance it is wrong
Certain
We’re certain about this datum